==> colobot_0.1.9.orig.tar.gz: colobot-colobot-gold-0.1.9-alpha/README.md <==
# Colobot: Gold Edition

Welcome to the Colobot: Gold Edition project code repository

This is official repository for the open-source Colobot: Gold Edition project developed by TerranovaTeam, part of International Colobot Community (ICC, previously known as Polish Portal of Colobot/PPC) with the official site at: [colobot.info](http://colobot.info/).

The source code contained here was released by Epsitec -- the original creator of the game -- on open source (GPLv3) license. The code was given and the rights granted specifically to ICC community in March 2012. Since then, we have been developing the game further.

More information for developers (in English) can be found on the [developer wiki](http://colobot.info/wiki/dev/) or [our forum](http://colobot.info/forum/). However, the freshest source of information is our IRC channels (see below).

This repository contains only the source code of the project. The game requires also data files which are now provided as git submodule and are hosted in [separate repository](https://github.com/colobot/colobot-data).


## Status

The original version of the game, as released to us by Epsitec, is available as download at [our download site](http://colobot.info/files/) along with original source code and related data files. However, we will not develop this version further, as we focused our efforts on new versions of the game. The original version is also known as Colobot Classic.

We are now working on refreshed and updated version of original game, codename Colobot Gold and this is the version currently hosted in this repository. The goal is to rewrite the game engine to be multi-platform, refresh the graphics, include some enhancements and refactor the code to make the game easier to modify.

The project at this point is in alpha stage - the game is mostly playable, both on Windows and Linux, and most major bugs have been corrected. We are now working steadily towards subsequent beta releases, correcting other bugs and introducing enhancements and new features. There is a lot of work ahead and we will gladly accept any and all help.

In the future, we will begin development on a new installment in the Colobot series, codename Colobot 2. We have many ideas for the new game and we are still discussing them. Generally, the development of this version will begin only after finishing Colobot Gold (it will be probably hosted in another repository, forked off the Colobot Gold code).


## Download packages

We provide compiled packages of most recent versions using an [automated build bot service](http://compiled.colobot.info/). Available versions include packages for Windows and Linux in both Release and Debug configurations.

On some Linux distributions there are also distribution packages available:
 * Debian Sid (unstable): http://packages.debian.org/sid/colobot
 * Arch Linux (AUR): https://aur.archlinux.org/packages/colobot-gold
 * openSUSE: http://software.opensuse.org/download.html?project=games&package=colobot


## Compiling and running the game

If you want to compile colobot yourself, see [INSTALL.md](INSTALL.md) file.

## Contributing

If you want to contribute to the project, see [CONTRIBUTING.md](CONTRIBUTING.md) file. It contains a lot of useful information on how to get started.

## Contact

If you want to help in the project, please contact us on our IRC channels or [our forum](http://colobot.info/forum/).

### IRC channels

* [#colobot on Freenode](irc://freenode.net#colobot) - main development channel (English);
* [#colobot on pirc.pl](irc://pirc.pl#colobot) - Polish community channel;

==> colobot_0.2.0.orig.tar.gz: colobot-colobot-gold-0.2.0-alpha/README.md <==
# Colobot: Gold Edition

Welcome to the Colobot: Gold Edition project code repository

This is official repository for the open-source Colobot: Gold Edition project developed by TerranovaTeam, part of International Colobot Community (ICC, previously known as Polish Portal of Colobot/PPC) with the official site at: [colobot.info](http://colobot.info/).

The source code contained here was released by Epsitec -- the original creator of the game -- on open source (GPLv3) license. The code was given and the rights granted specifically to ICC community in March 2012. Since then, we have been developing the game further.

More information for developers (in English) can be found on [our forum](http://colobot.info/forum/). However, the freshest source of information is our IRC channels (see below).

This repository contains only the source code of the project. The game requires also data files which are now provided as git submodule and are hosted in [separate repository](https://github.com/colobot/colobot-data).


## Status

The original version of the game, as released to us by Epsitec, is available as download at [our download site](http://colobot.info/files/) along with original source code and related data files. However, we will not develop this version further, as we focused our efforts on new versions of the game. The original version is also known as Colobot Classic.

We are now working on refreshed and updated version of original game, codename Colobot Gold and this is the version currently hosted in this repository. The goal is to rewrite the game engine to be multi-platform, refresh the graphics, include some enhancements and refactor the code to make the game easier to modify.

The project at this point is in alpha stage - the game is mostly playable, both on Windows and Linux, and most major bugs have been corrected. We are now working steadily towards subsequent beta releases, correcting other bugs and introducing enhancements and new features. There is a lot of work ahead and we will gladly accept any and all help.

In the future, we will begin development on a new installment in the Colobot series, codename Colobot 2. We have many ideas for the new game and we are still discussing them. Generally, the development of this version will begin only after finishing Colobot Gold (it will be probably hosted in another repository, forked off the Colobot Gold code).


## Download packages

We provide compiled packages of most recent versions using an [automated build bot service](http://compiled.colobot.info/). Available versions include packages for Windows and Linux in both Release and Debug configurations.

On some Linux distributions there are also distribution packages available:
 * Debian Sid (unstable): http://packages.debian.org/sid/colobot
 * Arch Linux (AUR): https://aur.archlinux.org/packages/colobot-gold
 * openSUSE: http://software.opensuse.org/download.html?project=games&package=colobot
 * Fedora: https://src.fedoraproject.org/rpms/colobot
 * Guix https://guix.gnu.org/en/packages/colobot-0.1.12-alpha/


## Compiling and running the game

If you want to compile colobot yourself, see [INSTALL.md](INSTALL.md) file.

## Contributing

If you want to contribute to the project, see [CONTRIBUTING.md](CONTRIBUTING.md) file. It contains a lot of useful information on how to get started.

## Contact

If you want to help in the project, please contact us on our [Discord server](https://discord.gg/56Fm9kb).
